==> iplass-core-3.0.9-sources.jar: org/iplass/mtp/entity/definition/listeners/SendNotificationType.java <==
/*
 * Copyright (C) 2018 INFORMATION SERVICES INTERNATIONAL - DENTSU, LTD. All Rights Reserved.
 *
 * Unless you have purchased a commercial license,
 * the following license terms apply:
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.iplass.mtp.entity.definition.listeners;

import org.iplass.mtp.definition.Definition;
import org.iplass.mtp.mail.template.definition.MailTemplateDefinition;
import org.iplass.mtp.pushnotification.template.definition.PushNotificationTemplateDefinition;
import org.iplass.mtp.sms.template.definition.SmsMailTemplateDefinition;

/**
 * 送信種別を表すenum。
 */
public enum SendNotificationType {

	MAIL("Mail", MailTemplateDefinition.class),
	SMS("SMS", SmsMailTemplateDefinition.class),
	PUSH("PushNotification", PushNotificationTemplateDefinition.class);

	private String displayName;
	private Class<? extends Definition> definitionClass;

	private SendNotificationType(String displayName, Class<? extends Definition> definitionClass) {
		this.displayName = displayName;
		this.definitionClass = definitionClass;
	}

	public String displayName() {
		return displayName;
	}

	public Class<? extends Definition> definitionClass() {
		return definitionClass;
	}
}

==> iplass-core-3.0.23-sources.jar: org/iplass/mtp/entity/definition/listeners/SendNotificationType.java <==
/*
 * Copyright (C) 2018 INFORMATION SERVICES INTERNATIONAL - DENTSU, LTD. All Rights Reserved.
 *
 * Unless you have purchased a commercial license,
 * the following license terms apply:
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.iplass.mtp.entity.definition.listeners;

import org.iplass.mtp.definition.Definition;
import org.iplass.mtp.mail.template.definition.MailTemplateDefinition;
import org.iplass.mtp.pushnotification.template.definition.PushNotificationTemplateDefinition;
import org.iplass.mtp.sms.template.definition.SmsMailTemplateDefinition;
import org.iplass.mtp.webhook.template.definition.WebHookTemplateDefinition;

/**
 * 送信種別を表すenum。
 */
public enum SendNotificationType {

	MAIL("Mail", MailTemplateDefinition.class),
	SMS("SMS", SmsMailTemplateDefinition.class),
	PUSH("PushNotification", PushNotificationTemplateDefinition.class),
	WEBHOOK("WebHook", WebHookTemplateDefinition.class);

	private String displayName;
	private Class<? extends Definition> definitionClass;

	private SendNotificationType(String displayName, Class<? extends Definition> definitionClass) {
		this.displayName = displayName;
		this.definitionClass = definitionClass;
	}

	public String displayName() {
		return displayName;
	}

	public Class<? extends Definition> definitionClass() {
		return definitionClass;
	}
}
